import { useState } from "react";
import { Input, Button, Card, Steps, Tag, Spin, message } from "antd";
import { SearchOutlined, SafetyCertificateOutlined } from "@ant-design/icons";
import ProgressHeader from "./ProgressHeader";
import { api } from "@nice/client";
import { LetterBadge } from "@web/src/components/models/post/LetterBadge";
import dayjs from "dayjs";


const { Step } = Steps;

export default function LetterProgressPage() {
	const [letterId, setLetterId] = useState<string | undefined>();
	const { data } = api.post.findFirst.useQuery({
		where: {
			id: letterId
		}
	}, { enabled: Boolean(letterId) })


	return (
		<div
			className="min-h-screen shadow-elegant border-2 border-white  rounded-xl    bg-gradient-to-b from-slate-100 to-slate-50 "
			style={{ fontFamily: "Arial, sans-serif" }}>
			<ProgressHeader></ProgressHeader>
			{/* Main Content */}
			<main className="container mx-auto p-6">
				<div className="space-y-4">
					<div className="flex gap-4">
						<Input
							prefix={
								<SearchOutlined className=" text-secondary-300" />
							}
							size="large"
							value={letterId}
							onChange={(e) => setLetterId(e.target.value)}
							placeholder="请输入信件编码查询处理状态"
							className="border border-gray-300"
						/>
					</div>

				</div>

				{/* Results Section */}
				{data && (
					<Card>
						<div className="space-y-6">
							{/* Header */}
							<div className="flex items-center justify-between border-b pb-4">
								<h2 className="text-xl font-semibold text-[#003366]">
									处理进度
								</h2>
								<LetterBadge type="state" value={data?.state}></LetterBadge>
							</div>

							{/* Details Grid */}
							<div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-4 gap-6">
								<div>
									<p className="text-sm text-gray-600">
										Ticket ID
									</p>
									<p className="font-medium text-[#003366]">
										{data.id}
									</p>
								</div>
								<div>
									<p className="text-sm text-gray-600">
										提交日期
									</p>
									<p className="font-medium text-[#003366]">
										{dayjs(data.createdAt).format('YYYY-MM-DD HH:mm:ss')}
									</p>
								</div>
								<div>
									<p className="text-sm text-gray-600">
										最后更新
									</p>
									<p className="font-medium text-[#003366]">
										{dayjs(data.updatedAt).format('YYYY-MM-DD HH:mm:ss')}
									</p>
								</div>
								<div>
									<p className="text-sm text-gray-600">
										标题
									</p>
									<p className="font-medium text-[#003366]">
										{data.title}
									</p>
								</div>
							</div>

							{/* Progress Timeline */}
							<div className="mt-8">
								<Steps
									current={
										data.state === "pending"
											? 0
											: data.state === "processing"
												? 1
												: 2
									}
									className="usa-progress">
									<Step
										title="Submitted"
										description="Ticket received"
										icon={<SafetyCertificateOutlined />}
									/>
									<Step
										title="In Progress"
										description="Under review"
										icon={<SafetyCertificateOutlined />}
									/>
									<Step
										title="Resolved"
										description="Ticket completed"
										icon={<SafetyCertificateOutlined />}
									/>
								</Steps>
							</div>
						</div>
					</Card>
				)}
			</main>
		</div>
	);
}
